#
# spec file for package python-kwant
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname kwant
%{?sle15_python_module_pythons}
Name:           python-kwant
Version:        1.5.0
Release:        1.1
Summary:        Python library for numerical quantum transport calculations
License:        BSD-2-Clause
URL:            https://kwant-project.org/
Source0:        https://files.pythonhosted.org/packages/source/k/kwant/kwant-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module numpy-devel >= 1.18 with %python-numpy-devel < 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  blas-devel
BuildRequires:  fdupes
BuildRequires:  lapack-devel
BuildRequires:  mumps-devel
BuildRequires:  python-rpm-macros
Requires:       python-scipy >= 1.3
Requires:       python-tinyarray
Requires:       (python-numpy >= 1.18 with python-numpy < 2)
Recommends:     python-matplotlib
Recommends:     python-qsymm
Recommends:     python-sympy
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 1.3}
BuildRequires:  %{python_module sympy >= 1.5}
BuildRequires:  %{python_module tinyarray}
# /SECTION
# mumps exclusion list is "i586 s390 ppc armv7l" (sic!)
ExcludeArch:    %ix86 %arm

%python_subpackages

%description
Kwant is a Python library for numerical calculations on tight-binding
models with a strong focus on quantum transport. Kwant can be used to
simulate a variety of systems and phenomena in quantum physics
including: metals, graphene, topological insulators, quantum Hall
effect, superconductivity, spintronics, molecular electronics, any
combination of the above, and many other things. Kwant can calculate
transport properties (conductance, noise, scattering matrix),
dispersion relations, modes, wave functions, various Green’s
functions, out-of-equilibrium local quantities.

%prep
%setup -q -n kwant-%{version}

%build
# CAN'T FIND mumps HEADERS
export CFLAGS="%{optflags} -I%{_includedir}/mumps"
%pyproject_wheel

%install
%pyproject_install

# REMOVE UNNEEDED HEADER FILE
%python_expand rm %{buildroot}%{$python_sitearch}/%{modname}/graph/defs.h

%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# TESTS CANNOT BE RUN FROM TOPLEVEL SOURCE DIR
mkdir testing && pushd testing
export PYTHONPATH+=%{buildroot}%{python3_sitearch}
export PYTHONDONTWRITEBYTECODE=1
python3 -c 'import kwant; kwant.test()'
popd

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE.rst
%{python_sitearch}/%{modname}
%{python_sitearch}/%{modname}-%{version}.dist-info

%changelog
* Fri Jul 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.5.0:
  * Deprecation of leaving ‘norbs’ unset for site families
  * Plotly for plots
  * Automatic addition of Peierls phase terms to Builders
  * Improved tutorial building
  * Discretization onto a Landau level basis
  * Removal of Umfpack support
  * Addition of python-mumps wrapper
- Restrict numpy to < 2 for now.
- Switch to pyproject macros.
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.4:
  * Ensure compatibility with recent versions of SymPy,
    matplotlib and Sphinx.
  * Fix current density plotting when sites coincide.
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.3:
  * Builder properly handles Hermitian conjugation of array-like
    values.
  * Various maintenance.
* Sat May 15 2021 Ben Greiner <code@bnavigator.de>
- Re-cythonize the .pyx sources for Python > 3.8 compatibility
  https://gitlab.kwant-project.org/kwant/kwant/-/issues/403
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python36 (scipy)
* Wed Jul  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
